Support — django-authority v0.2 documentation

### Navigation

- index
- next |
- previous |
- django-authority v0.2 documentation »

# Support

We’ve created a google group for django-authority. If you have questions or suggestions, please drop us a note.

For more specific issues and bug reports please use the issue tracker on django-authority’s Bitbucket page.

### Navigation

- index
- next |
- previous |
- django-authority v0.2 documentation »